@@ -53,8 +53,8 @@ namespace Rcpp {
 	// methods. The relationship between the index and the method needs to be kept'
 	// in sync with the R-bindings.
 	
-	template <> Rclusterpp::LinkageKinds as(SEXP x) throw(not_compatible);	
-	template <> Rclusterpp::DistanceKinds as(SEXP x) throw(not_compatible);
+	template <> Rclusterpp::LinkageKinds as(SEXP x);	
+	template <> Rclusterpp::DistanceKinds as(SEXP x);
 
 	template <> SEXP wrap( const Rclusterpp::Hclust& );
 	template <typename T> SEXP wrap( const Rclusterpp::ClusterVector<T>& ) ;
